@@ -4,10 +4,10 @@ var searchData=
   ['getaccessdeniedpage_212',['GetAccessDeniedPage',['../classionicsdk_1_1coverpage_1_1_cover_page_service.html#a670fb288ed010d10547d5cfe050724b6',1,'ionicsdk::coverpage::CoverPageService']]],
   ['getaccessgroup_213',['GetAccessGroup',['../classionicsdk_1_1keyvault_1_1_key_vault_apple_key_chain.html#a2fe3981c233fe61d892cf5a627693994',1,'ionicsdk::keyvault::KeyVaultAppleKeyChain']]],
   ['getaccountname_214',['GetAccountName',['../classionicsdk_1_1keyvault_1_1_key_vault_apple_key_chain.html#a7e36fd5ff70208a9740d7f34879414b3',1,'ionicsdk.keyvault.KeyVaultAppleKeyChain.GetAccountName()'],['../classionicsdk_1_1keyvault_1_1_key_vault_mac.html#acac61c931238c3b2e60e8644c43f53a3',1,'ionicsdk.keyvault.KeyVaultMac.GetAccountName()']]],
-  ['getactiveprofile_215',['getactiveprofile',['../classionicsdk_1_1agent_1_1_agent.html#a5d3ec7aa9da09348ae8c984b2bfccb1f',1,'ionicsdk.agent.Agent.getactiveprofile()'],['../classionicsdk_1_1services_1_1_agent_key_services_base.html#abcf473e091ee80d666461713cd96ad70',1,'ionicsdk.services.AgentKeyServicesBase.getactiveprofile()']]],
+  ['getactiveprofile_215',['getactiveprofile',['../classionicsdk_1_1agent_1_1_agent.html#a5d3ec7aa9da09348ae8c984b2bfccb1f',1,'ionicsdk.agent.Agent.getactiveprofile()'],['../classionicsdk_1_1profilemanager_1_1_profile_manager.html#acc3f827e9abfb67de7807bbdad0823ca',1,'ionicsdk.profilemanager.ProfileManager.getactiveprofile()'],['../classionicsdk_1_1services_1_1_agent_key_services_base.html#abcf473e091ee80d666461713cd96ad70',1,'ionicsdk.services.AgentKeyServicesBase.getactiveprofile()']]],
   ['getallkeyids_216',['GetAllKeyIds',['../classionicsdk_1_1keyvault_1_1_key_vault.html#a1bf97194b9f18a59dd060dd67d9d86a3',1,'ionicsdk::keyvault::KeyVault']]],
   ['getallkeys_217',['GetAllKeys',['../classionicsdk_1_1keyvault_1_1_key_vault.html#ae9130c0a981a948570d5e7cfcfdaf6bc',1,'ionicsdk::keyvault::KeyVault']]],
-  ['getallprofiles_218',['getallprofiles',['../classionicsdk_1_1agent_1_1_agent.html#abf21c280c3cd6bc1fea68be58e1ad0b9',1,'ionicsdk::agent::Agent']]],
+  ['getallprofiles_218',['getallprofiles',['../classionicsdk_1_1agent_1_1_agent.html#abf21c280c3cd6bc1fea68be58e1ad0b9',1,'ionicsdk.agent.Agent.getallprofiles()'],['../classionicsdk_1_1profilemanager_1_1_profile_manager.html#a74aa19784b95e9c96beccdc99c5f5b5c',1,'ionicsdk.profilemanager.ProfileManager.getallprofiles()']]],
   ['getcoverpage_219',['GetCoverPage',['../classionicsdk_1_1coverpage_1_1_cover_page_service.html#a03429e3ab4c8af146ecf4983e0937198',1,'ionicsdk::coverpage::CoverPageService']]],
   ['getdefaultaccountname_220',['GetDefaultAccountName',['../classionicsdk_1_1keyvault_1_1_key_vault_apple_key_chain.html#a40966995927957e6cb114f6a20efdbe4',1,'ionicsdk.keyvault.KeyVaultAppleKeyChain.GetDefaultAccountName()'],['../classionicsdk_1_1keyvault_1_1_key_vault_mac.html#a051f33e90da1e00c06e1a072e8be1bb8',1,'ionicsdk.keyvault.KeyVaultMac.GetDefaultAccountName()']]],
   ['getdefaultfilepath_221',['GetDefaultFilePath',['../classionicsdk_1_1keyvault_1_1_key_vault_mac.html#ab0611779b2d47cb53950f34a3afb4817',1,'ionicsdk.keyvault.KeyVaultMac.GetDefaultFilePath()'],['../classionicsdk_1_1keyvault_1_1_key_vault_windows_dp_api.html#a5550fa77c52ea6360d309d085b56b476',1,'ionicsdk.keyvault.KeyVaultWindowsDpApi.GetDefaultFilePath()']]],
@@ -17,7 +17,7 @@ var searchData=
   ['getids_225',['getids',['../classionicsdk_1_1common_1_1_key_data_list.html#a5e7d1653a97aefeaf9a2f0a67840a361',1,'ionicsdk.common.KeyDataList.getids()'],['../classionicsdk_1_1common_1_1_update_key_data_list.html#a5299be9cb2569c69bd00b6f34ddc026b',1,'ionicsdk.common.UpdateKeyDataList.getids()']]],
   ['getinfo_226',['getinfo',['../classionicsdk_1_1chunkcipher_1_1_chunk_crypto.html#a3d9f3fa7b9c37d7e15cb2b57e691dce1',1,'ionicsdk.chunkcipher.ChunkCrypto.getinfo()'],['../classionicsdk_1_1filecipher_1_1_file_crypto.html#aa65bbd3bf02e091fbd78564d798021b7',1,'ionicsdk.filecipher.FileCrypto.getinfo()'],['../classionicsdk_1_1filecipher_1_1_file_cipher_base.html#a14fd152a74cdc0b13a012bce0af12424',1,'ionicsdk.filecipher.FileCipherBase.getinfo()']]],
   ['getinfobytes_227',['getinfobytes',['../classionicsdk_1_1filecipher_1_1_file_crypto.html#a0398c75464082374e8cdd979fdfe05d1',1,'ionicsdk.filecipher.FileCrypto.getinfobytes()'],['../classionicsdk_1_1filecipher_1_1_file_cipher_base.html#ab5203a9b0514fe68d658595222fe4693',1,'ionicsdk.filecipher.FileCipherBase.getinfobytes()']]],
-  ['getkey_228',['GetKey',['../classionicsdk_1_1keyvault_1_1_key_vault.html#a5c29fa7ea7907ac03b2cd7b3688c7d8d',1,'ionicsdk.keyvault.KeyVault.GetKey()'],['../classionicsdk_1_1secretshare_1_1_secret_share_persistor.html#a085c4c7dee6c7e6419de36850c2a0c46',1,'ionicsdk.secretshare.SecretSharePersistor.GetKey()'],['../classionicsdk_1_1agent_1_1_agent.html#a046d44882bfbb1e55f32a0939b098779',1,'ionicsdk.agent.Agent.getkey()'],['../classionicsdk_1_1services_1_1_agent_key_services_base.html#a25624911589a1c9d71fee1feedfda1c9',1,'ionicsdk.services.AgentKeyServicesBase.getkey()']]],
+  ['getkey_228',['getkey',['../classionicsdk_1_1agent_1_1_agent.html#a046d44882bfbb1e55f32a0939b098779',1,'ionicsdk.agent.Agent.getkey()'],['../classionicsdk_1_1services_1_1_agent_key_services_base.html#a25624911589a1c9d71fee1feedfda1c9',1,'ionicsdk.services.AgentKeyServicesBase.getkey()'],['../classionicsdk_1_1keyvault_1_1_key_vault.html#a5c29fa7ea7907ac03b2cd7b3688c7d8d',1,'ionicsdk.keyvault.KeyVault.GetKey()'],['../classionicsdk_1_1secretshare_1_1_secret_share_persistor.html#a085c4c7dee6c7e6419de36850c2a0c46',1,'ionicsdk.secretshare.SecretSharePersistor.GetKey()']]],
   ['getkeycount_229',['GetKeyCount',['../classionicsdk_1_1keyvault_1_1_key_vault.html#a8204e52f296a9ac0fd5cc76d8df2d597',1,'ionicsdk::keyvault::KeyVault']]],
   ['getkeyerror_230',['GetKeyError',['../classionicsdk_1_1agent_1_1_get_key_error.html',1,'ionicsdk::agent']]],
   ['getkeyerrorlist_231',['GetKeyErrorList',['../classionicsdk_1_1agent_1_1_get_key_error_list.html',1,'ionicsdk::agent']]],
@@ -29,7 +29,7 @@ var searchData=
   ['getkeystate_237',['GetKeyState',['../classionicsdk_1_1keyvault_1_1_key_vault_custom.html#aaf229818a0aa1332b435d8fff9715dfd',1,'ionicsdk::keyvault::KeyVaultCustom']]],
   ['getlastserverresponse_238',['getLastServerResponse',['../classionicsdk_1_1agent_1_1_agent.html#aafda9e1dfd478ae3aa6de5dfe59a55a7',1,'ionicsdk.agent.Agent.getLastServerResponse()'],['../classionicsdk_1_1chunkcipher_1_1_chunk_cipher_base.html#af2a2bf70eb43286699f748c3fe8ae36d',1,'ionicsdk.chunkcipher.ChunkCipherBase.getLastServerResponse()'],['../classionicsdk_1_1filecipher_1_1_file_cipher_base.html#acf6dc81f2f8b7d08317c5dc680b82be3',1,'ionicsdk.filecipher.FileCipherBase.getLastServerResponse()']]],
   ['getmetadata_239',['getmetadata',['../classionicsdk_1_1agent_1_1_agent.html#a15118f18af8b915c4a629f3aca20a65e',1,'ionicsdk::agent::Agent']]],
-  ['getprofileforkeyid_240',['getprofileforkeyid',['../classionicsdk_1_1agent_1_1_agent.html#aff5ef627b82bb9e61c2aea1c28da8c2a',1,'ionicsdk::agent::Agent']]],
+  ['getprofileforkeyid_240',['getprofileforkeyid',['../classionicsdk_1_1agent_1_1_agent.html#aff5ef627b82bb9e61c2aea1c28da8c2a',1,'ionicsdk.agent.Agent.getprofileforkeyid()'],['../classionicsdk_1_1profilemanager_1_1_profile_manager.html#a4e018fe099f59132dc91efd3e42e9252',1,'ionicsdk.profilemanager.ProfileManager.getprofileforkeyid()']]],
   ['getprofilemanager_241',['getprofilemanager',['../classionicsdk_1_1agent_1_1_agent.html#add56ac182b78f52f1cdcd9800d4af84c',1,'ionicsdk::agent::Agent']]],
   ['getprotectionauthdata_242',['GetProtectionAuthData',['../classionicsdk_1_1keyvault_1_1_key_vault_apple_key_chain.html#a397dabb22632d3adfef587115b87b4d0',1,'ionicsdk::keyvault::KeyVaultAppleKeyChain']]],
   ['getprotectionkey_243',['GetProtectionKey',['../classionicsdk_1_1keyvault_1_1_key_vault_apple_key_chain.html#a3acd3ba9d257babbd7ecf995592e6ebb',1,'ionicsdk::keyvault::KeyVaultAppleKeyChain']]],
