@@ -9,7 +9,7 @@ var searchData=
   ['errors_276',['errors',['../namespaceionicsdk_1_1errors.html',1,'ionicsdk']]],
   ['exceptions_277',['exceptions',['../namespaceionicsdk_1_1exceptions.html',1,'ionicsdk']]],
   ['filecipher_278',['filecipher',['../namespaceionicsdk_1_1filecipher.html',1,'ionicsdk']]],
-  ['id_279',['id',['../classionicsdk_1_1common_1_1_key_data.html#ab225f878b49d59e2eb978b29c1bd1e5d',1,'ionicsdk.common.KeyData.id()'],['../classionicsdk_1_1chunkcipher_1_1_chunk_cipher_base.html#aec87c3aab833e63a8d6f279a91053e57',1,'ionicsdk.chunkcipher.ChunkCipherBase.id()'],['../classionicsdk_1_1chunkcipher_1_1_chunk_cipher_auto.html#aea2f0016e9873f3feee73f83bb2f954c',1,'ionicsdk.chunkcipher.ChunkCipherAuto.ID()'],['../classionicsdk_1_1chunkcipher_1_1_chunk_cipher_v1.html#a41e7a8d0b7c04f1a61c3de088719ba2f',1,'ionicsdk.chunkcipher.ChunkCipherV1.ID()'],['../classionicsdk_1_1chunkcipher_1_1_chunk_cipher_v2.html#a13360811bcbba18513213db34a6e5531',1,'ionicsdk.chunkcipher.ChunkCipherV2.ID()'],['../classionicsdk_1_1chunkcipher_1_1_chunk_cipher_v3.html#a87f9ae094360b3e0afbb2cbe52b0df8d',1,'ionicsdk.chunkcipher.ChunkCipherV3.ID()'],['../classionicsdk_1_1chunkcipher_1_1_chunk_cipher_v4.html#a784475d682187ce51bc8cf6d5a2ba08b',1,'ionicsdk.chunkcipher.ChunkCipherV4.ID()']]],
+  ['id_279',['ID',['../classionicsdk_1_1chunkcipher_1_1_chunk_cipher_auto.html#aea2f0016e9873f3feee73f83bb2f954c',1,'ionicsdk.chunkcipher.ChunkCipherAuto.ID()'],['../classionicsdk_1_1chunkcipher_1_1_chunk_cipher_v1.html#a41e7a8d0b7c04f1a61c3de088719ba2f',1,'ionicsdk.chunkcipher.ChunkCipherV1.ID()'],['../classionicsdk_1_1chunkcipher_1_1_chunk_cipher_v2.html#a13360811bcbba18513213db34a6e5531',1,'ionicsdk.chunkcipher.ChunkCipherV2.ID()'],['../classionicsdk_1_1chunkcipher_1_1_chunk_cipher_v3.html#a87f9ae094360b3e0afbb2cbe52b0df8d',1,'ionicsdk.chunkcipher.ChunkCipherV3.ID()'],['../classionicsdk_1_1chunkcipher_1_1_chunk_cipher_v4.html#a784475d682187ce51bc8cf6d5a2ba08b',1,'ionicsdk.chunkcipher.ChunkCipherV4.ID()'],['../classionicsdk_1_1common_1_1_key_data.html#ab225f878b49d59e2eb978b29c1bd1e5d',1,'ionicsdk.common.KeyData.id()'],['../classionicsdk_1_1chunkcipher_1_1_chunk_cipher_base.html#aec87c3aab833e63a8d6f279a91053e57',1,'ionicsdk.chunkcipher.ChunkCipherBase.id()']]],
   ['ionicerror_280',['IonicError',['../classionicsdk_1_1errors_1_1_ionic_error.html',1,'ionicsdk::errors']]],
   ['ionicexception_281',['IonicException',['../classionicsdk_1_1exceptions_1_1_ionic_exception.html',1,'ionicsdk::exceptions']]],
   ['ionicserverexception_282',['IonicServerException',['../classionicsdk_1_1exceptions_1_1_ionic_server_exception.html',1,'ionicsdk::exceptions']]],
@@ -43,6 +43,7 @@ var searchData=
   ['issuedservertimeutcseconds_310',['issuedServerTimeUtcSeconds',['../classionicsdk_1_1keyvault_1_1_key_vault_key_record.html#acb899050499add4b296e49c8c9ef86aa',1,'ionicsdk::keyvault::KeyVaultKeyRecord']]],
   ['keyvault_311',['keyvault',['../namespaceionicsdk_1_1keyvault.html',1,'ionicsdk']]],
   ['log_312',['log',['../namespaceionicsdk_1_1log.html',1,'ionicsdk']]],
-  ['secretshare_313',['secretshare',['../namespaceionicsdk_1_1secretshare.html',1,'ionicsdk']]],
-  ['services_314',['services',['../namespaceionicsdk_1_1services.html',1,'ionicsdk']]]
+  ['profilemanager_313',['profilemanager',['../namespaceionicsdk_1_1profilemanager.html',1,'ionicsdk']]],
+  ['secretshare_314',['secretshare',['../namespaceionicsdk_1_1secretshare.html',1,'ionicsdk']]],
+  ['services_315',['services',['../namespaceionicsdk_1_1services.html',1,'ionicsdk']]]
 ];
