@@ -1,7 +1,7 @@
 var indexSectionsWithContent =
 {
   0: "_abcdefghiklmnoprstuvw",
-  1: "acdfgikmrsu",
+  1: "acdfgikmprsu",
   2: "i",
   3: "_acdefghiklprstu",
   4: "abcdefghiklmnoprstuv",
