@@ -371,14 +371,18 @@ class Agent(AgentKeyServicesBase):
         """!An Agent object can be initialized with different profile
         persistors and a config object, or defaults
 
-        By default an Agent will load profiles from the platform-
-        specific device profile persistor (if one exists for the 
-        platform, otherwise an AGENT_NO_PROFILE_PERSISTOR IonicException
-        may be thrown if no other persistor is specified).  Loading can
-        be disabled, or a DeviceProfilePersistorPlaintextFile,
-        DeviceProfilePersistorPasswordFile, or
-        DeviceProfilePersistorAesGcmFile can be used to load profiles
-        from a file.
+        By default an Agent will load profiles from the platform-specific
+        device profile persistor (if one exists for the platform, otherwise
+        an AGENT_NO_PROFILE_PERSISTOR IonicException may be thrown if no other
+        persistor is specified).  Loading can be disabled, or a 
+        ionicsdk.common.DeviceProfilePersistorPlaintextFile,
+        ionicsdk.common.DeviceProfilePersistorPasswordFile, or
+        ionicsdk.common.DeviceProfilePersistorAesGcmFile can be used to load
+        profiles from a file.
+
+        Alternatively, an ionicsdk.profilemanager.ProfileManager can be
+        provided as a source from which to copy profiles without the additional
+        overhead of loading them from the system each time.
 
         An AgentConfig object or configuration file can specify network
         communication parameters.
@@ -441,16 +445,16 @@ class Agent(AgentKeyServicesBase):
         return ServerResponse._marshalFromC(self._cServerResponse)
 
     def getprofilemanager(self):
-        """!Get the profile manager object for this agent.
+        """!Get the ionicsdk.profilemanager.ProfileManager object for this agent.
             @return
-                A profile manager object that can be modified to change the agents behavior.
+                A ProfileManager object that can be modified to change the agents behavior.
         """
         return  ProfileManager(_cProfileManager=_private.cLib.ionic_agent_get_profile_manager(self._cAgent))
 
     # active profile
     def hasactiveprofile(self):
         """!(DEPRECATED) Determine if any device profile is active. 
-        @deprecated This function has moved to ProfileManager, accessible through
+        @deprecated This function has moved to ionicsdk.profilemanager.ProfileManager, accessible through
             getprofilemanager().  Time for removal is TBD.
         @return
             True if an active profile is loaded, False otherwise
@@ -459,7 +463,7 @@ class Agent(AgentKeyServicesBase):
 
     def setactiveprofile(self, deviceid):
         """!(DEPRECATED) Set the current device profile of the agent.
-        @deprecated This function has moved to ProfileManager, accessible through
+        @deprecated This function has moved to ionicsdk.profilemanager.ProfileManager, accessible through
             getprofilemanager().  Time for removal is TBD.
         @param
             deviceid (str): A string device id of a loaded profile to
@@ -477,7 +481,7 @@ class Agent(AgentKeyServicesBase):
 
     def getactiveprofile(self):
         """!(DEPRECATED) Get the current device profile of the agent.
-        @deprecated This function has moved to ProfileManager, accessible through
+        @deprecated This function has moved to ionicsdk.profilemanager.ProfileManager, accessible through
             getprofilemanager().  Time for removal is TBD.
         @return
             Returns the active device profile object. If no active
@@ -491,7 +495,7 @@ class Agent(AgentKeyServicesBase):
     # profile management
     def hasanyprofiles(self):
         """!(DEPRECATED) Determine if any device profiles are loaded.
-        @deprecated This function has moved to ProfileManager, accessible through
+        @deprecated This function has moved to ionicsdk.profilemanager.ProfileManager, accessible through
             getprofilemanager().  Time for removal is TBD.
         @return
             True if an any profile is loaded, False otherwise
@@ -500,7 +504,7 @@ class Agent(AgentKeyServicesBase):
 
     def getallprofiles(self):
         """!(DEPRECATED) Get all available device profiles.
-        @deprecated This function has moved to ProfileManager, accessible through
+        @deprecated This function has moved to ionicsdk.profilemanager.ProfileManager, accessible through
             getprofilemanager().  Time for removal is TBD.
         @return
             Returns a DeviceProfileList (subclass of list) of all device
@@ -514,7 +518,7 @@ class Agent(AgentKeyServicesBase):
 
     def addprofile(self, deviceprofile, makeactive = False):
         """!(DEPRECATED) Add a device profile to the agent device profile collection.
-        @deprecated This function has moved to ProfileManager, accessible through
+        @deprecated This function has moved to ionicsdk.profilemanager.ProfileManager, accessible through
             getprofilemanager().  Time for removal is TBD.
         @param
             deviceprofile (DeviceProfile): The device profile object.
@@ -534,7 +538,7 @@ class Agent(AgentKeyServicesBase):
 
     def removeprofile(self, deviceid):
         """!(DEPRECATED) Remove a device profile from the agent device profile list.
-        @deprecated This function has moved to ProfileManager, accessible through
+        @deprecated This function has moved to ionicsdk.profilemanager.ProfileManager, accessible through
             getprofilemanager().  Time for removal is TBD.
         @param
             deviceid (string): The device id of the profile to remove.
@@ -568,7 +572,7 @@ class Agent(AgentKeyServicesBase):
     def getprofileforkeyid(self, keyid):
         """!(DEPRECATED) Determine which device profile is associated with the
         provided key ID.
-        @deprecated This function has moved to ProfileManager, accessible through
+        @deprecated This function has moved to ionicsdk.profilemanager.ProfileManager, accessible through
             getprofilemanager().  Time for removal is TBD.
         @param
             keyid (string): The key ID for which to retrieve the
@@ -623,7 +627,7 @@ class Agent(AgentKeyServicesBase):
         If loading is not successful, then no changes are made to the
         state of the agent.
 
-        @deprecated This function has moved to ProfileManager, accessible through
+        @deprecated This function has moved to ionicsdk.profilemanager.ProfileManager, accessible through
             getprofilemanager().  Time for removal is TBD.
         @param
             persistor (DeviceProfilePersistorBase): The device profile
@@ -636,7 +640,7 @@ class Agent(AgentKeyServicesBase):
     def saveprofiles(self, persistor):
         """!(DEPRECATED) Save device profiles using the specified profile persistor.
 
-        @deprecated This function has moved to ProfileManager, accessible through
+        @deprecated This function has moved to ionicsdk.profilemanager.ProfileManager, accessible through
             getprofilemanager().  Time for removal is TBD.
         @param
             persistor (DeviceProfilePersistorBase): The device profile
