@@ -110,6 +110,8 @@ class KeyDataList(list):
     
     def findkey(self, keyid):
         """!Returns the key object with the matching ID, or None if not found.
+        @param
+            keyid (string): The key id to search for
         @return
             The KeyData if found, or None otherwise
         """
@@ -686,7 +688,7 @@ class DeviceProfilePersistorAesGcmFile(DeviceProfilePersistorBase):
         @param
             keydata (bytes): The raw key bytes.  It must be exactly 32 bytes in length.
         @param
-            authdata (bytes): The raw auth data.
+            authdata (bytes): The raw auth data. If None or empty, no AAD will be used.
         """
         super(DeviceProfilePersistorAesGcmFile,self).__init__()
         ##(unicode) File name and path where the encrypted JSON file will be located
