@@ -98,13 +98,13 @@ class FileCipherEncryptAttributes(object):
         """!Constructs encrypt attributes from passed in arguments.
             
         @param
-            attributes (agent::KeyAttributesDict) The key attributes to associate with the key used to encrypt the file
+            attributes (KeyAttributesDict) The key attributes to associate with the key used to encrypt the file
         @param
-            metadata (agent::MetadataDict) The metadata properties to send along with the HTTP request
+            metadata (MetadataDict) The metadata properties to send along with the HTTP request
         @param
             version (string) The file format version to encrypt with - It can be left empty to use the latest version (recommended).
         @param
-            mutableAttributes (agent::KeyAttributesDict) The key mutable attributes to associate with data chunk protection key
+            mutableAttributes (KeyAttributesDict) The key mutable attributes to associate with data chunk protection key
         @param
             enablePortionMarking (boolean) Determines if portion marking is enabled.
         """
@@ -117,11 +117,11 @@ class FileCipherEncryptAttributes(object):
         self.familyOut = None
         ##(string) The file format version to encrypt with - It can be left empty to use the latest version (recommended).
         self.version = version
-        ##(agent::KeyAttributesDict) The key attributes to associate with the key used to encrypt the file
+        ##(\link ionicsdk.common.KeyAttributesDict KeyAttributesDict \endlink) The key attributes to associate with the key used to encrypt the file
         self.attributes = attributes
-        ##(agent::KeyAttributesDict) The key mutable attributes to associate with data chunk protection key
+        ##(\link ionicsdk.common.KeyAttributesDict KeyAttributesDict \endlink) The key mutable attributes to associate with data chunk protection key
         self.mutableAttributes = mutableAttributes
-        ##(agent::MetadataDict) The metadata properties to send along with the HTTP request
+        ##(\link ionicsdk.common.MetadataDict MetadataDict \endlink) The metadata properties to send along with the HTTP request
         self.metadata = metadata
         ##(boolean) Determines if portion marking is enabled.
         self.enablePortionMarking = enablePortionMarking
@@ -160,7 +160,7 @@ class FileCipherDecryptAttributes(object):
         """!Constructor for decrypt attributes, can pass in metadata, and then assign any other member variables.
             
         @param
-            metadata (agent::MetadataDict) The metadata properties to send along with the HTTP request
+            metadata (MetadataDict) The metadata properties to send along with the HTTP request
         @param
             enableaccessdeniedpage (boolean) Indicate whether access denied page object should be populated in
                     the event that an access denied error is encountered.
@@ -174,16 +174,16 @@ class FileCipherDecryptAttributes(object):
         self.familyOut = None
         ##(string) The file cipher version the file was decrypted with
         self.versionOut = None
-        ##(agent.KeyAttributesDict): The key attributes associated with the key used to decrypt the file
+        ##(\link ionicsdk.common.KeyAttributesDict KeyAttributesDict \endlink): The key attributes associated with the key used to decrypt the file
         self.attributesOut = None
-        ##(agent::KeyAttributesDict) The key mutable attributes to associate with data chunk protection key
+        ##(\link ionicsdk.common.KeyAttributesDict KeyAttributesDict \endlink) The key mutable attributes to associate with data chunk protection key
         self.mutableAttributesOut = None
         ##(bytes) The access denied page
         self.accessdeniedpageOut = None
         ##(boolean) Indicate whether access denied page object should be populated in the event
         ##      that an access denied error is encountered.
         self.enableaccessdeniedpage = enableaccessdeniedpage
-        ##(agent.MetadataDict) The metadata properties to send along with the HTTP request
+        ##(\link ionicsdk.common.MetadataDict MetadataDict \endlink) The metadata properties to send along with the HTTP request
         self.metadata = metadata
             
     def _updateFromC(self, cFileDecryptAttributes):
@@ -311,13 +311,13 @@ class FileCipherBase(object):
         @param
             plaintextbytes (bytes): The binary plaintext input buffer.
         @param
-            attributes (agent.KeyAttributesDict, optional): The
+            attributes (keyAttributesDict, optional): The
                         attributes to use when creating a key to protect data.
         @param
-            metadata (agent.MetadataDict, optional): The metadata
+            metadata (metadataDict, optional): The metadata
                         properties to send along with the HTTP request.
         @param
-            mutableAttributes (agent::KeyAttributesDict): The key mutable attributes
+            mutableAttributes (keyAttributesDict): The key mutable attributes
                         to associate with data chunk protection key.
 
         @return
@@ -396,7 +396,7 @@ class FileCipherBase(object):
         @param
             ciphertextbytes (bytes): The binary ciphertext input buffer.
         @param
-            metadata (agent.MetadataDict, optional): The metadata
+            metadata (metadataDict, optional): The metadata
                          properties to send along with the HTTP request.
 
         @return
@@ -485,13 +485,13 @@ class FileCipherBase(object):
         @param
             filepath (string): The file to be encrypted in place.
         @param
-            attributes (agent.KeyAttributesDict, optional): The
+            attributes (keyAttributesDict, optional): The
                         attributes to use when creating a key to protect data.
         @param
-            metadata (agent.MetadataDict, optional): The metadata
+            metadata (metadataDict, optional): The metadata
                         properties to send along with the HTTP request.
         @param
-            mutableAttributes (agent::KeyAttributesDict): The key mutable attributes
+            mutableAttributes (keyAttributesDict): The key mutable attributes
                         to associate with data chunk protection key.
 
         @return
@@ -574,7 +574,7 @@ class FileCipherBase(object):
         @param
             filepath (string): The file to be decrypted in place.
         @param
-            metadata (agent.MetadataDict, optional): The metadata
+            metadata (metadataDict, optional): The metadata
                          properties to send along with the HTTP request.
 
         @return
@@ -658,13 +658,13 @@ class FileCipherBase(object):
         @param
             destpath (string): The output file path.
         @param
-            attributes (agent.KeyAttributesDict, optional): The
+            attributes (keyAttributesDict, optional): The
                     attributes to use when creating a key to protect data.
         @param
-            metadata (agent.MetadataDict, optional): The metadata
+            metadata (metadataDict, optional): The metadata
                     properties to send along with the HTTP request.
         @param
-            mutableAttributes (agent::KeyAttributesDict): The key mutable attributes
+            mutableAttributes (keyAttributesDict): The key mutable attributes
                     to associate with data chunk protection key.
 
         @return
@@ -750,7 +750,7 @@ class FileCipherBase(object):
         @param
             destpath (string): The output file path.
         @param
-            metadata (agent.MetadataDict, optional): The metadata
+            metadata (metadataDict, optional): The metadata
                          properties to send along with the HTTP request.
 
         @return
